@@ -25,10 +25,8 @@ using namespace bt;
 
 namespace kt
 {
-UPnPPlugin::UPnPPlugin(QObject *parent, const QVariantList & /*args*/)
-    : Plugin(parent)
-    , sock(nullptr)
-    , upnp_tab(nullptr)
+UPnPPlugin::UPnPPlugin(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
+    : Plugin(parent, data, args)
 {
 }
 
@@ -68,9 +66,5 @@ void UPnPPlugin::shutdown(bt::WaitJob *job)
     upnp_tab->shutdown(job);
 }
 
-bool UPnPPlugin::versionCheck(const QString &version) const
-{
-    return version == QStringLiteral(VERSION);
-}
 }
 #include "upnpplugin.moc"
